@@ -9,7 +9,7 @@
 package TBX::Min;
 use strict;
 use warnings;
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 # ABSTRACT: Read, write and edit TBX-Min files
 use subs qw(date_created directionality entries);
 use Class::Tiny qw(
@@ -124,14 +124,14 @@ sub _get_handle {
 }
 
 
-my %valid = map +($_=>1), Class::Tiny->get_all_attributes_for(__PACKAGE__);
+my %valid = map {+($_=>1)} Class::Tiny->get_all_attributes_for(__PACKAGE__);
 sub new {
     my ($class, $args) = @_;
     my $self;
     if((ref $args) eq 'HASH'){
 
         # validate arguments
-        if(my @invalids = grep !$valid{$_}, sort keys %$args){
+        if(my @invalids = grep {!$valid{$_}} sort keys %$args){
             croak 'Invalid attributes for class: ' .
                 join ' ', @invalids
         }
@@ -243,7 +243,7 @@ sub as_xml {
         my $entry_el = XML::Twig::Elt->new(
             termEntry => {$termEntry->id ? (id => $termEntry->id) : ()})->
             paste(last_child => $body);
-        my $entry_el_comment = XML::Twig::Elt->new( '#COMMENT', 'terminological entry')->
+        XML::Twig::Elt->new( '#COMMENT', 'terminological entry')->
             paste(last_child => $entry_el);
         if(my $sf = $termEntry->subject_field){
             XML::Twig::Elt->new(subjectField => $sf)->paste(
@@ -256,7 +256,7 @@ sub as_xml {
             for my $termGrp (@{$langGrp->term_groups}){
                 my $term_el = XML::Twig::Elt->new('tig')->paste(
                     last_child => $lang_el);
-                my $term_el_comment = XML::Twig::Elt->new( '#COMMENT', 'terminological information group')->
+                XML::Twig::Elt->new( '#COMMENT', 'terminological information group')->
 					paste(last_child => $term_el);
                 if (my $term = $termGrp->term){
                     XML::Twig::Elt->new(term => $term)->paste(
@@ -445,7 +445,7 @@ TBX::Min - Read, write and edit TBX-Min files
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -596,7 +596,7 @@ L<GitHub|https://github.com/byutrg/TBX-Spec>.
 
 =head1 AUTHOR
 
-James Hayes <james.s.hayes@gmail.com>
+Nathan Glenn <garfieldnate@gmail.com>, James Hayes <james.s.hayes@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
